@@ -18,12 +18,14 @@ from agent_build_refactored.tools.runner import (
     GitHubActionsSettings,
 )
 from agent_build_refactored.tools.constants import SOURCE_ROOT, AGENT_BUILD_PATH
+from agent_build_refactored.docker_image_builders import ALL_IMAGE_BUILDERS
+from agent_build_refactored.managed_packages.managed_packages_builders import ALL_MANAGED_PACKAGE_BUILDERS
 
 
 # Step that runs small script which installs requirements for the test/dev environment.
 INSTALL_TEST_REQUIREMENT_STEP = EnvironmentRunnerStep(
     name="install_test_requirements",
-    script_path=AGENT_BUILD_PATH / "scripts/steps/deploy-test-environment.sh",
+    script_path="agent_build_refactored/scripts/steps/deploy-test-environment.sh",
     tracked_files_globs=[AGENT_BUILD_PATH / "requirement-files/*.txt"],
     github_actions_settings=GitHubActionsSettings(cacheable=True),
 )
@@ -31,3 +33,9 @@ INSTALL_TEST_REQUIREMENT_STEP = EnvironmentRunnerStep(
 
 class BuildTestEnvironment(Runner):
     BASE_ENVIRONMENT = INSTALL_TEST_REQUIREMENT_STEP
+
+
+ALL_USED_BUILDERS = {
+    **ALL_IMAGE_BUILDERS,
+    **ALL_MANAGED_PACKAGE_BUILDERS
+}
