@@ -432,6 +432,25 @@ SCALYR_AGENT_ANNOTATION_CALCULATE_RATE_METRIC_NAMES = (
     "k8s.monitor.config.scalyr.com/calculate_rate_metric_names"
 )
 
+# A list of metric names for metrics used by Kubernetes Explorer functionality for which per second
+# rates should be calculated by the agent.
+CALCULATE_RATE_METRIC_NAMES = {
+    "node-exporter": [
+        # node-exporter metrics
+        "openmetrics_monitor:node_cpu_seconds_total",
+        "openmetrics_monitor:node_network_transmit_bytes_total",
+        "openmetrics_monitor:node_network_receive_bytes_total",
+        "openmetrics_monitor:node_disk_read_bytes_total",
+        "openmetrics_monitor:node_disk_written_bytes_total",
+    ],
+    "kubernetes-api-cadvisor": [
+        # Kubernetes API cAdvisor metrics
+        "openmetrics_monitor:container_cpu_usage_seconds_total",
+        "openmetrics_monitor:container_network_receive_bytes_total",
+        "openmetrics_monitor:container_network_transmit_bytes_total",
+    ],
+}
+
 
 # A regex to determine whether a string contains template directives
 TEMPLATE_RE = re.compile(r"\${[^}]+}")
@@ -753,6 +772,22 @@ class KubernetesOpenMetricsMonitor(ScalyrMonitor):
         if calculate_rate_metric_names is None:
             calculate_rate_metric_names = []
 
+        # Apply defaults from this file for mandatory metrics
+        # In case any custom values are specified as part of pod annotations, those are merged with
+        # the default values to avoid user from potentially breaking Kubernetes Explorer
+        # functionality by overriding required metrics
+        # NOTE: monitor_id contains pod name so we just check the id
+        if "node-exporter" in monitor_id:
+            calculate_rate_metric_names.extend(
+                CALCULATE_RATE_METRIC_NAMES["node-exporter"]
+            )
+        elif "kubernetes-api-cadvisor" in monitor_id:
+            calculate_rate_metric_names.extend(
+                CALCULATE_RATE_METRIC_NAMES["kubernetes-api-cadvisor"]
+            )
+
+        calculate_rate_metric_names = sorted(set(calculate_rate_metric_names))
+
         monitor_config = {
             "module": OPEN_METRICS_MONITOR_MODULE,
             "id": monitor_id,
@@ -828,9 +863,12 @@ class KubernetesOpenMetricsMonitor(ScalyrMonitor):
 
         # 1. Kubernetes API metrics monitor
         if self.__scrape_kubernetes_api_metrics:
+            monitor_id = f"{node_name}_kubernetes-api-metrics"
+            scrape_url = kubernetes_api_metrics_scrape_url
+
             monitor_config, log_config = self.__get_monitor_config_and_log_config(
-                monitor_id=f"{node_name}_kubernetes-api-metrics",
-                url=kubernetes_api_metrics_scrape_url,
+                monitor_id=monitor_id,
+                url=scrape_url,
                 verify_https=verify_https,
                 ca_file=ca_file,
                 headers=headers,
@@ -849,6 +887,13 @@ class KubernetesOpenMetricsMonitor(ScalyrMonitor):
                 include_cluster_name=self.__include_cluster_name,
             )
 
+            self._logger.debug(
+                f'Using monitor config options for scrape url "{scrape_url}" and monitor id "{monitor_id}": {monitor_config}'
+            )
+            self._logger.debug(
+                f'Using log config options for scrape url "{scrape_url}" and monitor id "{monitor_id}": {log_config}'
+            )
+
             monitor = monitors_manager.add_monitor(
                 monitor_config=monitor_config,
                 global_config=self._global_config,
@@ -871,9 +916,12 @@ class KubernetesOpenMetricsMonitor(ScalyrMonitor):
 
         # 2. Kubernetes API cAdvisor metrics monitor
         if self.__scrape_kubernetes_api_cadvisor_metrics:
+            monitor_id = f"{node_name}_kubernetes-api-cadvisor-metrics"
+            scrape_url = kubernetes_api_cadvisor_metrics_scrape_url
+
             monitor_config, log_config = self.__get_monitor_config_and_log_config(
-                monitor_id=f"{node_name}_kubernetes-api-cadvisor-metrics",
-                url=kubernetes_api_cadvisor_metrics_scrape_url,
+                monitor_id=monitor_id,
+                url=scrape_url,
                 verify_https=verify_https,
                 ca_file=ca_file,
                 headers=headers,
@@ -892,6 +940,13 @@ class KubernetesOpenMetricsMonitor(ScalyrMonitor):
                 include_cluster_name=self.__include_cluster_name,
             )
 
+            self._logger.debug(
+                f'Using monitor config options for scrape url "{scrape_url}" and monitor id "{monitor_id}": {monitor_config}'
+            )
+            self._logger.debug(
+                f'Using log config options for scrape url "{scrape_url}" and monitor id "{monitor_id}": {log_config}'
+            )
+
             monitor = monitors_manager.add_monitor(
                 monitor_config=monitor_config,
                 global_config=self._global_config,
@@ -999,8 +1054,9 @@ class KubernetesOpenMetricsMonitor(ScalyrMonitor):
             return
 
         node_name = self.__get_node_name()
+        monitor_id = f"{node_name}_{pod.name}"
         monitor_config, log_config = self.__get_monitor_config_and_log_config(
-            monitor_id=f"{node_name}_{pod.name}",
+            monitor_id=monitor_id,
             url=scrape_url,
             sample_interval=scrape_config.scrape_interval or self.__scrape_interval,
             scrape_timeout=scrape_config.scrape_timeout,
@@ -1027,10 +1083,10 @@ class KubernetesOpenMetricsMonitor(ScalyrMonitor):
             f'Started scrapping url "{scrape_url}" for pod {pod.namespace}/{pod.name} ({pod.uid})'
         )
         self._logger.debug(
-            f'Using monitor config options for scrape url "{scrape_url}": {monitor_config}'
+            f'Using monitor config options for scrape url "{scrape_url}" and monitor id "{monitor_id}": {monitor_config}'
         )
         self._logger.debug(
-            f'Using log config options for scrape url "{scrape_url}": {log_config}'
+            f'Using log config options for scrape url "{scrape_url}" and monitor id "{monitor_id}": {log_config}'
         )
 
         self.__add_watcher_log_config(
